@@ -3,9 +3,16 @@ import requests as req
 class TFA:
     def __init__(self, access_token) -> None:
         self.access_token = access_token
+        self.testUrl = "http://localhost:8000"
+        self.baseUrl = "https://tele-fa-api.herokuapp.com"
 
     def authUser(self, user_token):
-        response = req.get(f'https://tele-fa-api.herokuapp.com/api/access/{self.access_token}/{user_token}')
+        urlData = {
+            "access_token": self.access_token,
+            "user_token": user_token,
+        }
+
+        response = req.post(f'{self.baseUrl}/api/auth/access', json = urlData)
 
         data = {
             "status": response.status_code,
